@@ -486,14 +486,14 @@ bool DatabaseManager::hasPassword() {
 bool DatabaseManager::openDB(const QString & pas) {
 	initdb = false;
 
-	qDebug() << "open db with pas " << SOFT_VERSION;
+	//qDebug() << "open db with pas " << SOFT_VERSION;
 
 	if (!opendb)
 		opendb = _openDB("qtwallet.db.sqlite");
 
 	if (!opendb) return false;
 
-	qDebug() << "init db with pas";
+	//qDebug() << "init db with pas";
 
 	if (db.tables().count() == 0) {
 		if (initDB())
@@ -527,7 +527,7 @@ bool DatabaseManager::openDB(const QString & pas) {
 		}
 	}
 
-	qDebug() << "init db with pas " << initdb << " " << currentVersion;
+	//qDebug() << "init db with pas " << initdb << " " << currentVersion;
 
 	return initdb;
 }
@@ -798,7 +798,7 @@ void DatabaseManager::decrypt (const QByteArray& a, QByteArray& b)
 
 bool DatabaseManager::insertTarget(Target* target)
 {
-		qDebug() << "step 0" ;
+		//qDebug() << "step 0" ;
 
 	bool ret = false;
 	if (db.isOpen()) {
