@@ -7,18 +7,53 @@
 #include "Constants.h"
 
 QLabelZ::QLabelZ(const QString &text, QWidget *parent=0, Qt::WindowFlags f=0) : QLabel (text, parent, f) {
-//	QPixmap available(":/resources/number.png");
-//	setPixmap(available);
+	select = false;
 }
 QLabelZ::QLabelZ(QWidget *parent=0, Qt::WindowFlags f=0): QLabel (parent, f) {
+	select = false;
 }
 QLabelZ::~QLabelZ() {
+	select = false;
 }
-
-void QLabelZ::mousePressEvent(QMouseEvent *ev) {
-   	//qDebug () << "click on field " << this->userData(0);
+void QLabelZ::mouseReleaseEvent(QMouseEvent *ev) {
+	//qDebug () << "mouseReleaseEvent " << select << " " << ev;
+	if (select) {
+		select = false;
+		repaint ();
+	}
+	ev->accept();
    	emit clicked ();
-//    	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
+}
+void QLabelZ::mousePressEvent(QMouseEvent *ev) {
+	//qDebug () << "mousePressEvent " << select << " " << ev;
+	if (!select) {
+		select = true;
+		repaint ();
+	}
+	ev->accept();
+}
+void QLabelZ::paintEvent(QPaintEvent* event)
+{
+    QFrame::paintEvent(event);
+    QPainter painter(this);
+	QRect r = rect();
+    if (select) {
+		QBrush b(Qt::cyan, Qt::SolidPattern);
+		painter.setBrush(b);
+    }
+    else {
+		QBrush b(Qt::gray, Qt::SolidPattern);
+		painter.setBrush(b);
+    }
+
+	painter.setPen(Qt::cyan);
+	QPen pen = painter.pen();
+	pen.setWidth(2);
+	painter.setPen(pen);
+	painter.setOpacity(0.2);
+	painter.drawRoundedRect(r, 15, 15);
+
+   	QLabel::paintEvent(event);
 }
 
 LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)paTarget)
@@ -57,63 +92,45 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 
 		if (i == 9) {
 			text = tr("Ok");
-			imageButton[i] = new QLabelZ (text, this);
-//			componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
-
-			QObject::connect(imageButton[i], SIGNAL(clicked()), this, SLOT(acceptS()));
-		} else {
+		}
+		else {
 			if (i == 10) {
 				text = "0";
-				imageButton[i] = new QLabelZ (text, this);
-//				//imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-//				//imageButton[i] ->setFixedSize(80, 80);
-//				imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
-//				imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-//				imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-//				//imageButton[i] ->setIconSize(QSize(20, 20));
-//				componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
-
-				signalMapper->setMapping(imageButton[i], text);
-
-				QObject::connect(imageButton[i], SIGNAL(clicked()), signalMapper, SLOT(map()));
-			} else
+			}
+			else
 				if (i == 11) {
 					text = tr("Clear");
-					imageButton[i] = new QLabelZ (text, this);
-//					//imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_clear.png"),
-//					//imageButton[i] ->setFixedSize(80, 80);
-//					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
-//					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-//					imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-//					//imageButton[i] ->setIconSize(QSize(20, 20));
-//					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
+				}
+		}
 
-					//signalMapper->setMapping(imageButton[i], text);
+//		imageButton[i] = new QPushButton(QIcon(":/resources/number.png"), text, this); //
+//		imageButton[i]->setIconSize(QSize(B_SIZE, B_SIZE));
 
+		imageButton[i] = new QLabelZ (text, this);
+		//imageButton[i]->setFrameShadow(QFrame::Raised);
+		//imageButton[i]->setFrameShape(QFrame::StyledPanel);
+		imageButton[i]->setAlignment(Qt::AlignCenter);
+
+		imageButton[i]->setContextMenuPolicy(Qt::NoContextMenu);
+		imageButton[i]->setFocusPolicy(Qt::NoFocus);
+		imageButton[i]->setFont(QFont ("Arial", 22, 2, false));
+		componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
+		if (i == 9) {
+			QObject::connect(imageButton[i], SIGNAL(clicked()), this, SLOT(acceptS()));
+		}
+		else {
+			if (i == 10) {
+				signalMapper->setMapping(imageButton[i], text);
+				QObject::connect(imageButton[i], SIGNAL(clicked()), signalMapper, SLOT(map()));
+			}
+			else
+				if (i == 11) {
 					QObject::connect(imageButton[i], SIGNAL(clicked()), this, SLOT(clearS()));
 				} else {
-					imageButton[i] = new QLabelZ (text, this);
-//					//imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/number.png"),
-//					//imageButton[i] ->setFixedSize(80, 80);
-//					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
-//					imageButton[i] ->setFocusPolicy(Qt::NoFocus);
-//					imageButton[i] ->setFont(QFont ("Arial", 22, 2, false));
-//					//imageButton[i] ->setIconSize(QSize(20, 20));
-//					componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
-
 					signalMapper->setMapping(imageButton[i], text);
-
 					QObject::connect(imageButton[i], SIGNAL(clicked()), signalMapper, SLOT(map()));
 				}
 		}
-		imageButton[i]->setFrameShadow(QFrame::Raised);
-		imageButton[i]->setFrameShape(QFrame::StyledPanel);
-		imageButton[i]->setContextMenuPolicy(Qt::NoContextMenu);
-		imageButton[i]->setFocusPolicy(Qt::NoFocus);
-		imageButton[i]->setAlignment(Qt::AlignCenter);
-		imageButton[i]->setFont(QFont ("Arial", 22, 2, false));
-
-		componentLayout->addWidget(imageButton[i], i / 3, i % 3, 1, 1);
 	}
 
 	//componentLayout->addItem(new QSpacerItem(2,3), 4, 3, 3, 2);
@@ -126,7 +143,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	dlgBtnBox = new QDialogButtonBox(this);
 	dlgBtnBox->setOrientation(Qt::Vertical);
 
-	QPushButton * aboutButton = new QPushButton(/*QIcon(":/resources/about.png"), */"About", this);
+	QPushButton * aboutButton = new QPushButton(tr("About"), this);
 	aboutButton->setFixedHeight(70);
 	aboutButton->setContextMenuPolicy(Qt::NoContextMenu);
 	aboutButton->setFocusPolicy(Qt::NoFocus);
@@ -134,7 +151,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	QObject::connect(aboutButton, SIGNAL(clicked()), this, SLOT(about()));
 	dlgBtnBox->addButton(aboutButton, QDialogButtonBox::ActionRole);
 
-	QPushButton * donateButton = new QPushButton(/*QIcon(":/resources/donate.png"), */"Donate", this);
+	QPushButton * donateButton = new QPushButton(tr("Donate"), this);
 	donateButton->setFixedHeight(70);
 	donateButton->setContextMenuPolicy(Qt::NoContextMenu);
 	donateButton->setFocusPolicy(Qt::NoFocus);
@@ -142,15 +159,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	QObject::connect(donateButton, SIGNAL(clicked()), this, SLOT(donate()));
 	dlgBtnBox->addButton(donateButton, QDialogButtonBox::ActionRole);
 
-//	QPushButton * deleteButton = new QPushButton(QIcon(":/resources/delete.png"), "Delete DB", this);
-//	deleteButton->setFixedHeight(70);
-//	deleteButton->setContextMenuPolicy(Qt::NoContextMenu);
-//	deleteButton->setFocusPolicy(Qt::NoFocus);
-//	deleteButton->setIconSize(QSize(48, 48));
-//	QObject::connect(deleteButton, SIGNAL(clicked()), this->parent, SLOT(deleteDB()));
-//	dlgBtnBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
-
-	QPushButton * exitButton = new QPushButton(/*QIcon(":/resources/exit.png"), */"Exit", this);
+	QPushButton * exitButton = new QPushButton(tr("Exit"), this);
 	exitButton->setFixedHeight(70);
 	exitButton->setContextMenuPolicy(Qt::NoContextMenu);
 	exitButton->setFocusPolicy(Qt::NoFocus);
@@ -167,10 +176,6 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	setLayout(layout);
 
 	orientationChanged (0);
-//	this->setFocus ();
-//	label->setFocus ();
-//	this->focusNextChild();
-
 }
 
 void LoginDialog::orientationChanged(int o) {
