@@ -18,12 +18,15 @@ public:
 	QLabelZ(const QString &text, QWidget *parent, Qt::WindowFlags f);
 	QLabelZ(QWidget *parent, Qt::WindowFlags f);
 	~QLabelZ();
-
+	void paintEvent(QPaintEvent* event);
 signals:
 	void clicked ();
 
 protected:
     void mousePressEvent(QMouseEvent *ev);
+    void mouseReleaseEvent(QMouseEvent *ev);
+private:
+    bool select;
 };
 
 class LoginDialog : public QWidget
@@ -56,7 +59,7 @@ private:
 	int NTimes;
 	bool isFirstTime;
 	QString newPassword;
-	//QPushButton * imageButton [12];
+//	QPushButton * imageButton [12];
 	QLabelZ * imageButton [12];
 	QLineEdit * label;
 	QGridLayout * componentLayout;
