@@ -11,7 +11,6 @@
  * TODO sort after insert new card
  * TODO pc version?
  * TODO fix problems with key
- * TODO bigger login buttons
  */
 
 #include "eWallet.h"
@@ -32,8 +31,6 @@
 
 DatabaseManager * dbManager;
 
-
-
 RenameGroupDialog::RenameGroupDialog(QWidget *paTarget) : QDialog(paTarget)
 {
 	setContextMenuPolicy(Qt::NoContextMenu);
@@ -122,6 +119,7 @@ eWallet::eWallet(QString group, eWallet * _parent, QWidget *parent) : QMainWindo
 
 eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 {
+
 	isFirst = true;
 	currentGroup = "";
 	centralWidget = NULL;
@@ -547,7 +545,7 @@ void eWallet::loadTypesAndFields () {
 }
 
 void eWallet::keyPressEvent(QKeyEvent* event) {
-	//qDebug()<<"key pressed " << event->key();
+	qDebug()<<"key pressed " << event->key();
 	
 	if (!isAskPassword) {
 		if (searchField->isHidden()) {
@@ -1152,28 +1150,32 @@ void eWallet::deleteGroup () {
 }
 
 void eWallet::contextMenuEvent (QContextMenuEvent * event) {
-	////qDebug () << "Should be show " << this->childAt(event->globalPos());
+	//qDebug () << "Should be show " << this->childAt(event->globalPos());
+	if (isAskPassword) {
 
-	if (isShowGroups == 1) {
-		if (fnListWidget->currentRow() > 0) {
-			QMenu menu(this);
-			//menu.addAction(tr("View"), this, SLOT(_viewcTarget()));
-			menu.addAction(tr("Rename"), this, SLOT(renameGroup()));
-			menu.addAction(tr("Delete"), this, SLOT(deleteGroup()));
-			menu.exec(event->globalPos());
-		}
 	}
 	else {
-		if (fnListWidget->currentRow() >= 0) {
-			//Target * target = list.at(fnListWidget->currentRow());
+		if (isShowGroups == 1) {
+			if (fnListWidget->currentRow() > 0) {
+				QMenu menu(this);
+				//menu.addAction(tr("View"), this, SLOT(_viewcTarget()));
+				menu.addAction(tr("Rename"), this, SLOT(renameGroup()));
+				menu.addAction(tr("Delete"), this, SLOT(deleteGroup()));
+				menu.exec(event->globalPos());
+			}
+		}
+		else {
+			if (fnListWidget->currentRow() >= 0) {
+				//Target * target = list.at(fnListWidget->currentRow());
 
-			QMenu menu(this);
-			menu.addAction(tr("View"), this, SLOT(_viewcTarget()));
-			menu.addAction(tr("Edit"), this, SLOT(_editcTarget()));
-			menu.addAction(tr("New like this"), this, SLOT(_newLikeTarget()));
-			menu.addAction(tr("Duplicate"), this, SLOT(_duplicateTarget()));
-			menu.addAction(tr("Delete"), this, SLOT(_deletecTarget()));
-			menu.exec(event->globalPos());
+				QMenu menu(this);
+				menu.addAction(tr("View"), this, SLOT(_viewcTarget()));
+				menu.addAction(tr("Edit"), this, SLOT(_editcTarget()));
+				menu.addAction(tr("New like this"), this, SLOT(_newLikeTarget()));
+				menu.addAction(tr("Duplicate"), this, SLOT(_duplicateTarget()));
+				menu.addAction(tr("Delete"), this, SLOT(_deletecTarget()));
+				menu.exec(event->globalPos());
+			}
 		}
 	}
 }
@@ -1371,6 +1373,8 @@ void eWallet::closeEvent(QCloseEvent *event){
 }
 
 void eWallet::askPassword () {
+	setContextMenuPolicy(Qt::NoContextMenu);
+
 	times = 0;
 	
 	isAskPassword = true;
